==> rust-web-sys_0.3.60.orig.tar.gz: web-sys-0.3.60/src/features/gen_StorageManager.rs <==
#![allow(unused_imports)]
use super::*;
use wasm_bindgen::prelude::*;
#[wasm_bindgen]
extern "C" {
    # [wasm_bindgen (extends = :: js_sys :: Object , js_name = StorageManager , typescript_type = "StorageManager")]
    #[derive(Debug, Clone, PartialEq, Eq)]
    #[doc = "The `StorageManager` class."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    pub type StorageManager;
    # [wasm_bindgen (catch , method , structural , js_class = "StorageManager" , js_name = estimate)]
    #[doc = "The `estimate()` method."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager/estimate)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    pub fn estimate(this: &StorageManager) -> Result<::js_sys::Promise, JsValue>;
    # [wasm_bindgen (catch , method , structural , js_class = "StorageManager" , js_name = persist)]
    #[doc = "The `persist()` method."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager/persist)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    pub fn persist(this: &StorageManager) -> Result<::js_sys::Promise, JsValue>;
    # [wasm_bindgen (catch , method , structural , js_class = "StorageManager" , js_name = persisted)]
    #[doc = "The `persisted()` method."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager/persisted)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    pub fn persisted(this: &StorageManager) -> Result<::js_sys::Promise, JsValue>;
}

==> rust-web-sys_0.3.64.orig.tar.gz: web-sys-0.3.64/src/features/gen_StorageManager.rs <==
#![allow(unused_imports)]
#![allow(clippy::all)]
use super::*;
use wasm_bindgen::prelude::*;
#[wasm_bindgen]
extern "C" {
    # [wasm_bindgen (extends = :: js_sys :: Object , js_name = StorageManager , typescript_type = "StorageManager")]
    #[derive(Debug, Clone, PartialEq, Eq)]
    #[doc = "The `StorageManager` class."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    pub type StorageManager;
    # [wasm_bindgen (catch , method , structural , js_class = "StorageManager" , js_name = estimate)]
    #[doc = "The `estimate()` method."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager/estimate)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    pub fn estimate(this: &StorageManager) -> Result<::js_sys::Promise, JsValue>;
    #[cfg(web_sys_unstable_apis)]
    # [wasm_bindgen (method , structural , js_class = "StorageManager" , js_name = getDirectory)]
    #[doc = "The `getDirectory()` method."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager/getDirectory)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://rustwasm.github.io/docs/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub fn get_directory(this: &StorageManager) -> ::js_sys::Promise;
    # [wasm_bindgen (catch , method , structural , js_class = "StorageManager" , js_name = persist)]
    #[doc = "The `persist()` method."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager/persist)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    pub fn persist(this: &StorageManager) -> Result<::js_sys::Promise, JsValue>;
    # [wasm_bindgen (catch , method , structural , js_class = "StorageManager" , js_name = persisted)]
    #[doc = "The `persisted()` method."]
    #[doc = ""]
    #[doc = "[MDN Documentation](https://developer.mozilla.org/en-US/docs/Web/API/StorageManager/persisted)"]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `StorageManager`*"]
    pub fn persisted(this: &StorageManager) -> Result<::js_sys::Promise, JsValue>;
}
